"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const StorageError_1 = tslib_1.__importDefault(require("./StorageError"));
const defaultID = "DefaultID";
class StorageErrorFactory {
    static getInvalidHeaderValue(context, additionalMessages) {
        if (additionalMessages === undefined) {
            additionalMessages = {};
        }
        return new StorageError_1.default(400, "InvalidHeaderValue", "The value for one of the HTTP headers is not in the correct format.", context.contextID || defaultID, additionalMessages, context);
    }
    static getInvalidInput(context, additionalMessages) {
        if (additionalMessages === undefined) {
            additionalMessages = {};
        }
        return new StorageError_1.default(400, "InvalidInput", "An error occurred while processing this request.", context.contextID || defaultID, additionalMessages, context);
    }
    static getTableAlreadyExists(context) {
        return new StorageError_1.default(409, "TableAlreadyExists", "The table specified already exists.", context.contextID || defaultID, undefined, context);
    }
    static getTableNameEmpty(context) {
        return new StorageError_1.default(400, "TableNameEmpty", "The specified table name is empty.", context.contextID || defaultID, undefined, context);
    }
    static getInvalidOperation(context, message = "") {
        return new StorageError_1.default(400, "InvalidOperation", message, context.contextID || "", undefined, context);
    }
    static getAuthorizationSourceIPMismatch(context) {
        return new StorageError_1.default(403, "AuthorizationSourceIPMismatch", "This request is not authorized to perform this operation using this source IP {SourceIP}.", context.contextID || defaultID, undefined, context);
    }
    static getAuthorizationProtocolMismatch(context) {
        return new StorageError_1.default(403, "AuthorizationProtocolMismatch", "This request is not authorized to perform this operation using this protocol.", context.contextID || defaultID, undefined, context);
    }
    static getAuthorizationPermissionMismatch(context) {
        return new StorageError_1.default(403, "AuthorizationPermissionMismatch", "This request is not authorized to perform this operation using this permission.", context.contextID || defaultID, undefined, context);
    }
    static getAuthorizationServiceMismatch(context) {
        return new StorageError_1.default(403, "AuthorizationServiceMismatch", "This request is not authorized to perform this operation using this service.", context.contextID || defaultID, undefined, context);
    }
    static getAuthorizationResourceTypeMismatch(context) {
        return new StorageError_1.default(403, "AuthorizationResourceTypeMismatch", "This request is not authorized to perform this operation using this resource type.", context.contextID || defaultID, undefined, context);
    }
    static getAccountNameEmpty(context) {
        return new StorageError_1.default(400, "AccountNameEmpty", "The specified account name is empty.", context.contextID || defaultID, undefined, context);
    }
    static getTableNotExist(context) {
        return new StorageError_1.default(404, "TableNotFound", "The table specified does not exist.", context.contextID || defaultID, undefined, context);
    }
    static getAuthorizationFailure(context) {
        return new StorageError_1.default(403, "AuthorizationFailure", 
        // tslint:disable-next-line:max-line-length
        "Server failed to authenticate the request. Make sure the value of the Authorization header is formed correctly including the signature.", context.contextID || defaultID, undefined, context);
    }
    static getEntityAlreadyExist(context) {
        return new StorageError_1.default(409, "EntityAlreadyExists", "The specified entity already exists.", context.contextID || defaultID, undefined, context);
    }
    static getPropertiesNeedValue(context) {
        return new StorageError_1.default(400, "PropertiesNeedValue", "The values are not specified for all properties in the entity.", context.contextID || defaultID, undefined, context);
    }
    static getAtomFormatNotSupported(context) {
        return new StorageError_1.default(415, "AtomFormatNotSupported", "Atom format is not supported.", context.contextID || defaultID, undefined, context);
    }
    static getPreconditionFailed(context) {
        return new StorageError_1.default(412, "UpdateConditionNotSatisfied", "The update condition specified in the request was not satisfied.", context.contextID || defaultID, undefined, context);
    }
    static getTableNotFound(context) {
        return new StorageError_1.default(404, "TableNotFound", "The table specified does not exist.", context.contextID || defaultID, undefined, context);
    }
    static ResourceNotFound(context) {
        return new StorageError_1.default(404, "ResourceNotFound", "The specified resource does not exist.", context.contextID || defaultID, undefined, context);
    }
    static getEntityNotFound(context) {
        return new StorageError_1.default(404, "ResourceNotFound", "The specified resource does not exist.", context.contextID || defaultID, undefined, context);
    }
    static getQueryConditionInvalid(context) {
        return new StorageError_1.default(400, "InvalidInput", "The query condition specified in the request is invalid.", context.contextID || defaultID, undefined, context);
    }
    static getInvalidResourceName(context) {
        return new StorageError_1.default(400, "", `The specifed resource name contains invalid characters.`, context.contextID || defaultID, undefined, context);
    }
    static getOutOfRangeName(context) {
        return new StorageError_1.default(400, "", `The specified resource name length is not within the permissible limits.`, context.contextID || defaultID, undefined, context);
    }
}
exports.default = StorageErrorFactory;
//# sourceMappingURL=StorageErrorFactory.js.map